potentials_analytical_nanochannel <-
function(surface_charge_density=-0.1,channel_height=1e-8,c0=1e-3,er=78,T=293)
{

	
	
	# Required units:
	# surface_charge_density: C/m^2, signed
	# channel_half_height: m
	# c0 (bulk salt concentration): mol/L
	
	# Due to the symmetry, we need to consider half the channel
	
	channel_half_height = channel_height/2
	
	# Constants
	
	e0=8.85e-12 # Vacuum permittivity
	
	kB=1.38e-23 # Boltzmann constant
	
	qe=1.6e-19 # Elementary charge
	
	Na=6.022e23 # Avogadros number
	
	
	
	# Normalize charge of polymer to have only 
	
	sign_charge_wall=sign(surface_charge_density)
	
	sign_charge_wall[sign_charge_wall>=0]=1
	
	sign_charge_wall[sign_charge_wall<0]=-1
	
	
	# Make all variables the same length
	
	lmax=max(length (surface_charge_density) ,
		  length( channel_half_height),
		  length( sign_charge_wall) , 
	      length( c0) , 
	      length( er) , 
	      length( T))
	
	
	complete_length<-function(x,lmax)
	{
		if(length(x)<lmax)
		{
			x = c(x,rep(x[length(x)],lmax-length(x)))
		}
		
		return(x)
		
	}
	
	surface_charge_density=complete_length(surface_charge_density,lmax)
	channel_half_height=complete_length(channel_half_height,lmax)
	sign_charge_wall=complete_length(sign_charge_wall,lmax)
	c0=complete_length(c0,lmax)
	er=complete_length(er,lmax)
	T=complete_length(T,lmax)
	
	Vth=kB*T/qe # Thermal voltage
	
	lDebye = sqrt(e0*er*kB*T/2/Na/qe^2/c0/1000)
	
	# High potential case first	
	phi_0 = 2*sign_charge_wall*Vth*log(abs(surface_charge_density)/sqrt(2*e0*er*kB*T*Na*c0*1000))
	
	# Correct the values where Vth is not reached:
	low_phi_0 = abs(surface_charge_density)/sqrt(2*e0*er*kB*T*Na*c0*1000)<exp(0.5)
	
	phi_0[low_phi_0]=lDebye[low_phi_0]/tanh(channel_half_height[low_phi_0]/lDebye[low_phi_0])*surface_charge_density[low_phi_0]/er[low_phi_0]/e0
	
	
	approximation = vector(mode="character",length=length(phi_0))
	
	
	
	# Decide on weak or strong overlap
	
	
	overlap_thickness = 2*sqrt(2)*(exp(-1/2)-exp(-abs(phi_0)/Vth))*lDebye
	
	overlap_thickness[overlap_thickness<0]=0
	
	overlap_thickness_store = overlap_thickness
	
	# When phi_0 never reaches the thermal level, there is no overlap either
	
	overlap_thickness[low_phi_0]=0
	
	# For the moment, assume weak overlap, we will correct afterwards for the elements where this is not true
	
	phi_m = sign_charge_wall*Vth/cosh((channel_half_height-overlap_thickness)/lDebye)
	
	# Correct those values that have strong overlap, e.g., where the overlap thickness is larger than the pore radius
	
	
	get_strong_overlap_phi_m<-function(phi0,rpore_to_ldebye,Vth_single)
	{
		
		lower_limit_phim=0
		
		upper_limit_phim=log(pi*sqrt(2)/rpore_to_ldebye)*Vth_single*2*(1-1e-4)
		
		phim_initial_guess=upper_limit_phim/2
		
		return(coefficients(nls(phi0 ~ phim-2*Vth_single*log(cos(rpore_to_ldebye/2/sqrt(2)*exp(phim/2/Vth_single))),start=list(phim=phim_initial_guess),algorithm="port",
			lower=list(phim=lower_limit_phim),upper=list(phim=upper_limit_phim)))[["phim"]])		
	}
	
	for(index in 1:length(overlap_thickness))
	{
		if(overlap_thickness[index]>channel_half_height[index])
		{
			phi_m[index] = sign_charge_wall[index]*get_strong_overlap_phi_m(abs(phi_0[index]),channel_half_height[index]/lDebye[index],Vth[index])
			approximation[index]="Strong Overlap"
		} else
		{
			approximation[index]="Weak Overlap"
		}
		
		
	}
	
	approximation[low_phi_0]="Debye-Hueckel"
	
	# There is one case left out here, that is strong overlap despite Debye Hueckel (very weak charge density but small pores)
	
	debye_hueckel_and_strong_overlap = low_phi_0 & (lDebye>channel_half_height)
	
	
	phi_0[debye_hueckel_and_strong_overlap]=lDebye[debye_hueckel_and_strong_overlap]/
		tanh(channel_half_height[debye_hueckel_and_strong_overlap]/lDebye[debye_hueckel_and_strong_overlap])*surface_charge_density[debye_hueckel_and_strong_overlap]/
		er[debye_hueckel_and_strong_overlap]/e0
	
	phi_m[debye_hueckel_and_strong_overlap]=phi_0[debye_hueckel_and_strong_overlap]/cosh(channel_half_height[debye_hueckel_and_strong_overlap]/lDebye[debye_hueckel_and_strong_overlap])
	
	approximation[debye_hueckel_and_strong_overlap]="Debye-Hueckel with strong overlap"
	
	phi_m[approximation=="Debye-Hueckel"]=phi_0[approximation=="Debye-Hueckel"]/cosh(channel_half_height[approximation=="Debye-Hueckel"]/lDebye[approximation=="Debye-Hueckel"])
	
	return(list("phi_m"=phi_m,"phi_0"=phi_0,"approximation"=approximation))
		

	
	
}

