\name{integrate_poisson_boltzmann_1D}
\alias{integrate_poisson_boltzmann_1D}

\title{
integrate_poisson_boltzmann_1D
}
\description{
Evaluates the Poisson equation for known charge density distribution. The Poisson equation is given by:\cr\cr
\code{d2phi/dx2 = -charge_density/er/epsilon0} \cr\cr
where \code{er} is the relative permittivity, and \code{epsilon_0} is the vacuum permittivity (\code{8.85e-12})
}
\usage{
integrate_poisson_boltzmann_1D(charge_density,delta_x=1e-10,intrinsic_charge_density=1e7,er=78,phi0=0,dphidx0=0,Temperature=293)
}

\arguments{
  \item{charge_density}{
 Charge density (in C/m3); this should be a vector.
}
  \item{delta_x}{
The spacing between the points of the \code{charge_density} vector.
}
\item{intrinsic_charge_density}{Concentration of free salt in the bulk solution, here specified in Coulomb per cubic meter (C/m3) of one of the ions (positive number).
}
  \item{er}{
The relative permittivity of the medium
}
  \item{phi0}{
The potential at \code{x=0}
}
\item{dphidx0}{First derivative of the potential at \code{x=0}}
\item{Temperature}{Absolute temperature in Kelvins}
}
\details{
The Poisson equation is a second order differential equation, and hence two initial values are required to specify a given solution; the two boundary values are \code{phi0} and \code{dphidx0}.\cr\cr
Care should be taken to supply the charge_density in the correct units, as charge concentrations are usually given in mol/L in chemistry, but C/m^3 is needed for electrostatics. The integration is carried out by the assumption that 
the structure is in contact with a bulk monovalent salt solution, with imposed concentration. The argument \code{intrinsic_charge_density} describes the concentration of the bulk salt solution. Attention should again be paid to the 
units, as the units required here are the electrostatic units of C/m3, and not mol/L as usually for chemical concentrations.
}
\value{
Returns the electric potential values; vector of length identical to \code{charge_density}
}

\author{
Thomas Braschler}

\examples{
# 1Molar  positively charged region, then 1M negatively charged region
# This makes a PN junction. For an intrinsic salt concentration of 0.01M, the Nernst potentials should be 0.025*log(100) respectively -0.025*log(100) and should correspond to the simulated potentials
N_avogadro = 6.022e23
elementary_charge=1.6e-19
charge_density=c(rep(1,100),rep(-1,100))*1000*N_avogadro*elementary_charge
intrinsic_charge_density = 0.01*1000*N_avogadro*elementary_charge
delta_x=0.05e-9
er=78
x=((1:200)-1)*delta_x
# phi for known numerical solution
phi=integrate_poisson_boltzmann_1D(charge_density=charge_density,delta_x=delta_x,intrinsic_charge_density=intrinsic_charge_density,er=er,phi0=0.116270941346,dphidx0=0,Temperature=293)
plot(x*1e9,phi,xlab="x [nm]",ylab="Electric potential [V]",main="Potential distribution at a pn junction\nBulk salt concentration 0.1M")
lines(c(0,8),1.38e-23*293/elementary_charge*log(1/0.01)*c(1,1),col="red",type="l")
lines(c(2,10),-1.38e-23*293/elementary_charge*log(1/0.01)*c(1,1),col="red",type="l")
}
\keyword{ misc }

