\name{partition_coefficient_analytical_from_potentials}
\alias{partition_coefficient_analytical_from_potentials}


\title{
partition_coefficient_analytical_from_potentials
}
\description{
Partition coefficient under the Poisson-Boltzmann equation in a nanoslit, provided that the electric potential at the walls and in the channel midline is known. This is a suitably weighted average of the partition coefficients that would be expected at the different locations of the channel.
}
\usage{
partition_coefficient_analytical_from_potentials(phi_m = -0.05, phi_0 = -0.2, Vth=0.025, n_tracer=-1)
}

\arguments{
  \item{phi_m}{
Potential at the channel midline.
}
  \item{phi_0}{
Height of the nanoslits, in meters.
}
 \item{Vth}{Thermal voltage (i.e. Boltzmann constant times absolute temperature divided by elementary charge, 25mV at ambient temperature)}
\item{n_tracer}{Valency of the tracer ion of interest}
}
\details{
There is no known closed solution for the electric potential distribution \code{phi(x)} for the Poisson-Boltzmann equation. Nevertheless, an exact expression for the electric field \code{dphi/dx} in a nanoslit filled with a monovalent electrolyte solution is known (Overbeek, 1956), including when the potential largely exceeds the thermal voltage. Based on this expression for the electric field, it is possible to find an integral allowing to macroscopic quantities such as the partition coefficient. This function evaluates numerically such an integral for the partition coefficient of a tracer ion. More precisely, it evaluates eq. 10 of the paper by Braschler et al. This allows to estimate the partition coefficient provided the potential at the channel midline and the channel walls are known, without the need to find the explicit distribution of \code{phi(x)}. \cr\cr
The function will work only if \code{phi_m} and \code{phi_0} are of the same sign, and \code{abs(phi_0)>=abs(phi_m)}, and also \code{|phi_m|>0}. Indeed, other cases are unphysical in a symmetric nanoslit if finite height.
}
\value{
Predicted partition coefficient. Single number if all the arguments are single numbers, or vector of length equal to the longest argument vector. If arguments of different length are given, the function will pad the shorter ones by repeating their last element.
}
\author{
Thomas Braschler
}


\examples{

phi_m=seq(from=0.01,to=0.199,by=0.001)

phi_0 = 0.2

K_phi_m=partition_coefficient_analytical_from_potentials(phi_m = phi_m, phi_0 = phi_0, n_tracer=1)

phi_m_2=0.01

phi_0_2=seq(from=0.01,to=0.199,by=0.001)

K_phi_0=partition_coefficient_analytical_from_potentials(phi_m = phi_m_2, phi_0 = phi_0_2, n_tracer=1)

plot(phi_m,K_phi_m,log="xy",ylim=c(1e-4,1),xlab="Potential",ylab="Partition coefficient co-ion",type="p",
main="Control of K by phi_0 or phi_m")

lines(phi_0_2,K_phi_0,type="p",col="red")

legend("bottomleft",legend=c("By variation of the wall potential (phi_0)","By variation of the midline potential (phi_m)"),pch=c(1,1),col=c("red","black"))




}

\references{
"Soft nanofluidics governing minority ion exclusion in charged hydrogels", Braschler et al., Soft Matter, 2015\cr
P. Debye and E. Hueckel, Physikalische Zeitschrift, 1923, 24, 185-206.
J. T. Overbeek, Prog Biophys Biophys Chem, 1956, 6, 57-84
}

\keyword{ misc }

