\name{partition_coefficient_analytical_hydrogel}
\alias{partition_coefficient_analytical_hydrogel}


\title{
partition_coefficient_analytical_hydrogel
}
\description{
Analytical approximation to the partition coefficient in a hydrogel as modeled by the Poisson-Boltzmann equation 1D nanochannels. The function estimates equivalent pore size and surface charge from molecular and physico-chemical properties of the polymer making up the hydrogel: \code{strand_diameter}, \code{dry_density_polymer}, \code{molar_mass_per_polymer_charge}, \code{sign_charge_polymer} and also the \code{polymer_concentration}. It then treats the hydrogel as equivalent to a single 1D nanochannel, and provides an estimation of the partition coefficient for a tracer ion with valency \code{n_tracer} in the presence of a monovalent salt at bulk concentration given by \code{c0}. This partition coefficient gives the ratio of the concentration of the tracer ion inside the gel as compared to a surrounding bulk bath. 
}
\usage{
partition_coefficient_analytical_hydrogel(polymer_concentration=50,strand_diameter=0.6e-9,dry_density_polymer=1500,molar_mass_per_polymer_charge=200,sign_charge_polymer=-1,n_tracer=-1,
c0=1e-3,er=78,T=293,return_details=FALSE)
}

\arguments{
  \item{polymer_concentration}{
The polymer concentration in g/L. As many hydrogels swell differently in solution of different ionic strength, care should be taken that this is the final polymer concentration. 
}
  \item{strand_diameter}{
Molecular diameter of the polymer strands making up the hydrogel, in units of meters.
}
  \item{dry_density_polymer}{
The density of the polymer in its dry state. Units of g/L=kg/cubic meter.
}
   \item{molar_mass_per_polymer_charge}{
Molar mass per unit charge along the polymer. Units of g/mol
}
\item{sign_charge_polymer}{Sign of the charges carried by the polymer. Provide \code{1} or {-1}}
\item{n_tracer}{Valency (=number of elementary charges) of the tracer ion to be considered. No units}
\item{c0}{Bulk concentration of monovalent salt such as KCl in equilibrium with the hydrogel. Units of mol/L}
\item{er}{Relative electric permittivity of the medium. No units. For water ambient temperature, this is 78.}
\item{T}{Absolute temperature. Units of Kelvin}
\item{return_details}{If true, the function returns not only the numerical value of \code{K}, but also the potential in the middle of the pores as \code{attr(K,"phi_m"} and near the polymer strands as \code{attr(K,"phi_0")}
}}
\details{
This function evaluates an approximate partition coefficient by analytical approximations to the Poisson-Boltzmann equation. As a generic restriction, it assumes that a large excess of monovalent salt such as KCl is present compared to the tracer ion of interest (or alternatively that the tracer ion is the anion or cation of the monovalent salt itself); the function does not deal with multivalent bulk ions. The function is based on the paper "Soft nanofluidics governing minority ion exclusion in charged hydrogels", Braschler et al., Soft Matter, 2015, which in turn is based on the developments by Overbeek(1956). The function basically evaluates the partition coefficient by means of equation 10 of this paper, with details given in the Electronic Supplementary Information 6, to which the user is referred here.\cr\cr
The function works by distinguishing three scenarios. For the weakest surface charges and highest bulk salt concentrations, it uses the Debye-Hueckel approximation; for progressively stronger electric potentials, it then uses first the weak and then the strong double layer overlap scenarios descirbed in Braschler et al. As all of these regimes are approximations only, there are some jumps at the boundaries, and the results will also be only approximative compared to numerical solution of the Poisson-Boltzmann equations.\cr\cr
Finally, the arguments of the function can be single numerical values or vectors of numerical values.\cr\cr
Internally, the function makes use of \link{partition_coefficient_analytical_nanochannel} with the surface charge and channel half width as determined from the molecular parameters of the hydrogel
}
\value{
Predicted partition coefficient. Single number if all the arguments are single numbers, or vector of length equal to the longest argument vector. If arguments of different length are given, the function will pad the shorter ones by repeating their last element. If \code{return_details} is set to true, the function will return a more detailed output as attributes of the output number or vector. These values can be accessed via the \code{attr} and \code{attributes} function. They include the potentials near the polymer strands (attribute "phi_0"), the potential in the channel midline (attribute "phi_m"), and the approximation used (attribute "approximation").
}
\author{
Thomas Braschler
}


\examples{

# Example covering all 3 regimes, showing both the general agreement and the discontinuities at the transition

c0=10^(seq(from=-3,to=0,by=0.1))

K=partition_coefficient_analytical_hydrogel(molar_mass_per_polymer_charge=2000,c0=c0,return_details=TRUE)

plot(c0,K,log="x",xlab="KCl concentration [M]",ylab="Partition coefficient co-ion",main="Partition coefficient vs. ionic force",ylim=c(0,1))
dev.new()
plot(c0,attr(K,"phi_0"),log="x",xlab="KCl concentration [M]",ylab="Potential at polymer strands",main="Potential at polymer strands vs. ionic force")	
dev.new()
plot(c0,attr(K,"phi_m"),log="x",xlab="KCl concentration [M]",ylab="Potential at channel midline",main="Potential at pore midline vs. ionic force")


}

\references{
"Soft nanofluidics governing minority ion exclusion in charged hydrogels", Braschler et al., Soft Matter, 2015\cr
P. Debye and E. Hueckel, Physikalische Zeitschrift, 1923, 24, 185-206.
J. T. Overbeek, Prog Biophys Biophys Chem, 1956, 6, 57-84
}

\keyword{ misc }

