\name{partition_coefficient_analytical_nanochannel}
\alias{partition_coefficient_analytical_nanochannel}


\title{
partition_coefficient_analytical_nanochannel
}
\description{
Analytical approximation to the partition coefficient in a single 1D nanochannel (e.g., a nanoslit of infinite width, but given height) for a tracer ion with valency \code{n_tracer} in the presence of a monovalent salt at bulk concentration given by \code{c0}. This partition coefficient gives the ratio of the concentration of the tracer ion inside the nanochannel as compared to a surrounding bulk bath. 
}
\usage{
partition_coefficient_analytical_nanochannel(surface_charge_density=-0.1,channel_height=1e-8,n_tracer=-1,
c0=1e-3,er=78,T=293,return_details=FALSE)
}

\arguments{
  \item{surface_charge_density}{
Surface charge density of the channel walls, units of coulomb per square meters. Can be positive or negative.
}
  \item{channel_height}{
Height of the nanoslits, in meters.
}
 \item{n_tracer}{Valency (=number of elementary charges) of the tracer ion to be considered. No units}
\item{c0}{Bulk concentration of monovalent salt such as KCl in equilibrium with the hydrogel. Units of mol/L}
\item{er}{Relative electric permittivity of the medium. No units. For water ambient temperature, this is 78.}
\item{T}{Absolute temperature. Units of Kelvin}
\item{return_details}{If true, the function returns not only the numerical value of \code{K}, but also the potential in the middle of the channel as \code{attr(K,"phi_m"} and at the channel walls\code{attr(K,"phi_0")}
}}
\details{
This function evaluates an approximate partition coefficient by analytical approximations to the Poisson-Boltzmann equation. As a generic restriction, it assumes that a large excess of monovalent salt such as KCl is present compared to the tracer ion of interest (or alternatively that the tracer ion is the anion or cation of the monovalent salt itself); the function does not deal with multivalent bulk ions, but does have the capacity to handle multivalent tracer ions by means of the argument \code{n_tracer}. The function is based on the paper "Soft nanofluidics governing minority ion exclusion in charged hydrogels", Braschler et al., Soft Matter, 2015, in turn based on Overbeek (1956). It basically evaluates the partition coefficient by means of equation 10 of Braschler paper, with details given in its Electronic Supplementary Information 6, to which the user is referred here.\cr\cr
The function works by distinguishing three scenarios. For the weakest surface charges and highest bulk salt concentrations, it uses the Debye-Hueckel approximation; for progressively stronger electric potentials, it then uses first the weak and then the strong double layer overlap scenarios described in Braschler et al. As all of these regimes are approximations only, there are some jumps at the boundaries, and the results will also be only approximative compared to numerical solution of the Poisson-Boltzmann equations.\cr\cr
Finally, the arguments of the function can be single numerical values or vectors of numerical values.\cr\cr
Internally, the function makes use of \link{potentials_analytical_nanochannel} to estimate the necessary potentials at walls and channel midline, and then of \link{partition_coefficient_analytical_from_potentials} to calculate the partition coefficient from these potentials.
}
\value{
Predicted partition coefficient. Single number if all the arguments are single numbers, or vector of length equal to the longest argument vector. If arguments of different length are given, the function will pad the shorter ones by repeating their last element. If \code{return_details} is set to true, the function will return a more detailed output as attributes of the output number or vector. These values can be accessed via the \code{attr} and \code{attributes} function. They include the potentials near the polymer strands (attribute "phi_0"), the potential in the channel midline (attribute "phi_m"), and the approximation used (attribute "approximation").
}
\author{
Thomas Braschler
}


\examples{

# Example showing the limited effect of high charge density at higher pore sizes

c0=0.1
surface_charge_density=10^seq(from=-3,to=0,by=0.1)


n_tracer=1;




K_10nm=partition_coefficient_analytical_nanochannel(surface_charge_density=surface_charge_density,c0=c0,channel_height=1e-8,n_tracer=n_tracer,return_details=TRUE)
K_5nm=partition_coefficient_analytical_nanochannel(surface_charge_density=surface_charge_density,c0=c0,channel_height=5e-9,n_tracer=n_tracer,return_details=TRUE)
K_2nm=partition_coefficient_analytical_nanochannel(surface_charge_density=surface_charge_density,c0=c0,channel_height=2e-9,n_tracer=n_tracer,return_details=TRUE)


plot(surface_charge_density,K_10nm,log="xy",xlab="Surface charge density [C/m^2]",ylab="Partition coefficient monovalent co-ion",ylim=c(0.01,1),type="b",col="black",
	main="K as a function of surface charge")
lines(surface_charge_density,K_5nm,type="b",col="blue")
lines(surface_charge_density,K_2nm,type="b",col="red")


legend("bottomleft",legend=c("10nm channel","5nm channel","2nm channel"),pch=c(1,1,1),col=c("black","blue","red"),lty=c(1,1,1))



}

\references{
"Soft nanofluidics governing minority ion exclusion in charged hydrogels", Braschler et al., Soft Matter, 2015\cr
P. Debye and E. Hueckel, Physikalische Zeitschrift, 1923, 24, 185-206.
J. T. Overbeek, Prog Biophys Biophys Chem, 1956, 6, 57-84
}

\keyword{ misc }

