\name{poisson.boltzmann.1D-package}
\alias{poisson.boltzmann.1D-package}
\alias{poisson.boltzmann.1D}
\docType{package}
\title{
poisson.boltzmann.1D package}
\description{
Solution of the Poisson-Boltzmann equation in 1D under periodic boundary conditions. There are two parts to the package. The numeric part allows for arbitrary charge distribution, but is relatively slow. The main function of this part is \code{\link{solve_poisson_boltzmann}}. There is a second part offering analytical approximations, for the case of a nanochannel bounded by charged walls, but otherwise free of fixed space charge. The main function of this part is \code{\link{partition_coefficient_analytical_nanochannel}}, along with a version adapted to modeling charged hydrogels as 1D periodic nanochannels (\code{\link{partition_coefficient_analytical_hydrogel}}
}
\details{
\tabular{ll}{
Package: \tab poisson.boltzmann.1D\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2015-02-17\cr
License: \tab None\cr
LazyLoad: \tab yes\cr
}
}
\author{
Thomas Braschler (thomas.braschler@gmail.com)
}
\keyword{ package }

\examples{

# Example 1: Numerical part

# Numerical part: Construction of an example fixed charge distribution, and solution for the electric potential and monovalent ionic concentrations
# ==================================================================================================

# Positively charged region, and adjacent free solution without fixed charge
fixed_charge_concentration=c(rep(0.1,250),rep(0,375)) # These are molar concentrations

# Delta x well below the Debye length
delta_x=0.04e-9

# Water as a solvent, with relative permittivity of 78
er=78
# Bulk salt concentration of 10mM, which is 10x less than the fixed space charge concentration in the charged region
c_intrinsic=0.01

# Get the solution to the Poisson-Boltzmann equation under boundary conditions of symmetry (dphi/dx=0 on both sides
solutionPB=solve_poisson_boltzmann(fixed_charge_concentration=fixed_charge_concentration,
	delta_x=delta_x,c_intrinsic=c_intrinsic,er=er)
	
# We need an x coordinate for plotting purposes
x=((1:length(fixed_charge_concentration))-1)*delta_x

# We will need two plots on top of each other, the first for the electric potential, the second for the ionic concentrations

par(mfrow=c(2,1))



plot(x*1e9,fixed_charge_concentration*1000,type="l",col="blue",main="Ionic concentrations",xlab="x[nm]",ylab="concentration [mM]")

plot.xy(xy.coords(x*1e9,solutionPB[["positive"]]*1000),type="l",col="red")

plot.xy(xy.coords(x*1e9,solutionPB[["negative"]]*1000),type="l",col="green")

legend("topright",legend=c("Fixed space charge","Mobile anions","Mobile cations"),lty=c(1,1,1),col=c("blue","green","red"))

plot(x*1e9,solutionPB[["phi"]]*1000,type="l",col="black",main="Electric potential",xlab="x[nm]",ylab="Potential [mV]")

# Back to standard plotting
par(mfrow=c(1,1))




# Example 2: Analytical part

# Analytical part: Partition coefficients expected in a highly charged hydrogel of constant concentration, under variable ionic force
# ==================================================================================================



# Ionic force: Bulk monovalent salt concentration
c0=10^(seq(from=-4,to=0,by=0.1))

K_10g_per_L=partition_coefficient_analytical_hydrogel(molar_mass_per_polymer_charge=200,c0=c0,return_details=TRUE,polymer_concentration = 10)


K_30g_per_L=partition_coefficient_analytical_hydrogel(molar_mass_per_polymer_charge=200,c0=c0,return_details=TRUE,polymer_concentration = 30)

K_100g_per_L=partition_coefficient_analytical_hydrogel(molar_mass_per_polymer_charge=200,c0=c0,return_details=TRUE,polymer_concentration = 100)


# The steps arise due to switchover of different approximations
plot(c0,K_10g_per_L,log="xy",xlab="KCl concentration [M]",ylab="Partition coefficient co-ion",main="Partition coefficient vs. ionic force",ylim=c(1e-4,1))

lines(c0,K_30g_per_L,type="p",col="red")

lines(c0,K_100g_per_L,type="p",col="blue")

legend("bottomright",legend=c("10g/L","30g/L","100g/L"),pch=c(1,1,1),col=c("black","red","blue"))


}
