\name{potentials_analytical_nanochannel}
\alias{potentials_analytical_nanochannel}


\title{
potentials_analytical_nanochannel
}
\description{
Analytical approximation to the potential at the walls and at the channel midline in a single 1D nanochannel (e.g., a nanoslit of infinite width, but given height) for a tracer ion with valency \code{n_tracer} in the presence of a monovalent salt at bulk concentration given by \code{c0}.
}
\usage{
potentials_analytical_nanochannel(surface_charge_density=-0.1,channel_height=1e-8,c0=1e-3,er=78,T=293)
}

\arguments{
  \item{surface_charge_density}{
Surface charge density of the channel walls, units of coulomb per square meters. Can be positive or negative.
}
  \item{channel_height}{
Height of the nanoslits, in meters.
}
\item{c0}{Bulk concentration of monovalent salt such as KCl in equilibrium with the hydrogel. Units of mol/L}
\item{er}{Relative electric permittivity of the medium. No units. For water ambient temperature, this is 78.}
\item{T}{Absolute temperature. Units of Kelvin}
}
\details{
This function indicates approximate values for the electric potentials at the channel midline \code{phi_m} and walls \code{phi_0} under the Poisson-Boltzmann equation. The function assumes the presence of a monovalent salt at bulk concentration \code{c0}. The function is based on the paper "Soft nanofluidics governing minority ion exclusion in charged hydrogels", Braschler et al., Soft Matter, 2015. It is an implementation of the analytical approximations for the potentials described in the electronic supplementary material 6 of this paper, which are in turn based on the developments by Overbeek(1956) and the Debye-Hueckel approximation. \cr\cr
The function works by distinguishing three scenarios. For the weakest surface charges and highest bulk salt concentrations, it uses the Debye-Hueckel approximation; for progressively stronger electric potentials, it then uses first the weak and then the strong double layer overlap scenarios described in Braschler et al. As all of these regimes are approximations only, there are some jumps at the boundaries, and the results will also be only approximative compared to numerical solution of the Poisson-Boltzmann equations.\cr\cr
Finally, the arguments of the function can be single numerical values or vectors of numerical values.
}
\value{
List of three elements: "phi_m" containing the potentials at channel midline, "phi_0" containing the potentials at the channel edges, and "approximation" the approximation used. Each of these elements can be a number or a vector, depending on the arguments given to the function)
}
\author{
Thomas Braschler
}


\examples{

# Example showing the limited effect of high charge density at higher pore sizes

c0=0.05
surface_charge_density=10^seq(from=-2.5,to=0,by=0.1)


n_tracer=1;

potentials=potentials_analytical_nanochannel(surface_charge_density=surface_charge_density,channel_height=1e-8,c0=c0)

plot(surface_charge_density,potentials[["phi_0"]]*1000,type="b",log="xy",xlab="Surface charge density [C/m^2]",ylab="Potential [mV]",ylim=c(0.2,200),
main="Potential vs. surface charge density")

lines(surface_charge_density,potentials[["phi_m"]]*1000,type="b",col="red")

legend("bottomright",legend=c("Channel wall","Midline"),pch=c(1,1),lty=c(1,1),col=c("black","red"))


}

\references{
"Soft nanofluidics governing minority ion exclusion in charged hydrogels", Braschler et al., Soft Matter, 2015\cr
P. Debye and E. Hueckel, Physikalische Zeitschrift, 1923, 24, 185-206.
J. T. Overbeek, Prog Biophys Biophys Chem, 1956, 6, 57-84

}

\keyword{ misc }

