\name{solve_poisson_boltzmann}
\alias{solve_poisson_boltzmann}

\title{
solve_poisson_boltzmann
}
\description{
Solves the Poisson-Boltzmann equation for a monovalent salt with a bulk concentration given \code{c_intrinsic}
}
\usage{
solve_poisson_boltzmann(fixed_charge_concentration,delta_x=1e-11,c_intrinsic=1e-3,Temperature=293,er=78)
}

\arguments{
  \item{fixed_charge_concentration}{
The distribution of the fixed space charge, expressed in molar concentration. This variable is a vector, the values are for points separated by \code{delta_x}
}
  \item{delta_x}{
Spacing between the sample points
}
  \item{c_intrinsic}{
Bulk molar concentration of the monovalent salt
}
   \item{Temperature}{
Absolute temperature (in K)
}
\item{er}{Relative electric permittivity of the medium}
}
\details{
This function solves the Poisson-Boltzmann equation, trying to satisfy symmetry boundary conditions on both \code{x=0} and \code{x=xmax}: \code{dphidx(x=0)=0} and \code{dphidx(x=xmax)=0}
}
\value{
A list of three elements:\cr\cr
"positive": The local concentrations of the positively charged species; vector of the same length as \code{fixed_charge_concentration}\cr
"negative": The local concentrations of the negatively charged species; vector of the same length as \code{fixed_charge_concentration}\cr
"phi":The local electric potential\cr
}
\author{
Thomas Braschler
}


\examples{

# With an arbitrary charge distribution

# Construction of an example fixed charge distribution (here, diode type), and solution for the electric potential and monovalent ionic concentrations
# ==================================================================================================

# Positively charged region, and adjacent free solution without fixed charge
fixed_charge_concentration=c(rep(0.1,250),rep(-0.1,250)) # These are molar concentrations

# Delta x well below the Debye length
delta_x=0.04e-9

# Water as a solvent, with relative permittivity of 78
er=78
# Bulk salt concentration of 10mM, which is 10x less than the fixed space charge concentration in the charged region
c_intrinsic=0.01

# Get the solution to the Poisson-Boltzmann equation under boundary conditions of symmetry (dphi/dx=0 on both sides
solutionPB=solve_poisson_boltzmann(fixed_charge_concentration=fixed_charge_concentration,
	delta_x=delta_x,c_intrinsic=c_intrinsic,er=er)
	
# We need an x coordinate for plotting purposes
x=((1:length(fixed_charge_concentration))-1)*delta_x

# We will need two plots on top of each other, the first for the electric potential, the second for the ionic concentrations

par(mfrow=c(2,1))



plot(x*1e9,fixed_charge_concentration*1000,type="l",col="blue",main="Ionic concentrations",xlab="x[nm]",ylab="concentration [mM]")

plot.xy(xy.coords(x*1e9,solutionPB[["positive"]]*1000),type="l",col="red")

plot.xy(xy.coords(x*1e9,solutionPB[["negative"]]*1000),type="l",col="green")

legend("topright",legend=c("Fixed space charge","Mobile anions","Mobile cations"),lty=c(1,1,1),col=c("blue","green","red"))

plot(x*1e9,solutionPB[["phi"]]*1000,type="l",col="black",main="Electric potential",xlab="x[nm]",ylab="Potential [mV]")

# Back to standard plotting
par(mfrow=c(1,1))





	


}

\keyword{ misc }

